pub struct fillPermit2Call {
pub outputs: Vec<<Output as SolType>::RustType>,
pub permit2: <Permit2Batch as SolType>::RustType,
}Expand description
Function with signature fillPermit2((address,uint256,address,uint32)[],(((address,uint256)[],uint256,uint256),address,bytes)) and selector 0x1bbf03a8.
function fillPermit2(IOrders.Output[] memory outputs, UsesPermit2.Permit2Batch memory permit2) external;Fields
outputs: Vec<<Output as SolType>::RustType>permit2: <Permit2Batch as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for fillPermit2Call
impl Clone for fillPermit2Call
Sourcefn clone(&self) -> fillPermit2Call
fn clone(&self) -> fillPermit2Call
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for fillPermit2Call
impl Debug for fillPermit2Call
Sourceimpl<'de> Deserialize<'de> for fillPermit2Call
impl<'de> Deserialize<'de> for fillPermit2Call
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for fillPermit2Call
impl PartialEq for fillPermit2Call
Sourceimpl Serialize for fillPermit2Call
impl Serialize for fillPermit2Call
Sourceimpl SolCall for fillPermit2Call
impl SolCall for fillPermit2Call
Sourceconst SIGNATURE: &'static str = "fillPermit2((address,uint256,address,uint32)[],(((address,uint256)[],uint256,uint256),address,bytes))"
const SIGNATURE: &'static str = "fillPermit2((address,uint256,address,uint32)[],(((address,uint256)[],uint256,uint256),address,bytes))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Array<Output>, Permit2Batch)
type Parameters<'a> = (Array<Output>, Permit2Batch)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<fillPermit2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<fillPermit2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = fillPermit2Return
type Return = fillPermit2Return
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<fillPermit2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<fillPermit2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8], validate: bool) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
fn abi_decode(data: &[u8], validate: bool) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for fillPermit2Call
impl StructuralPartialEq for fillPermit2Call