pub struct OrdersInstance<T, P, N = Ethereum> { /* private fields */ }Expand description
A Orders instance.
Contains type-safe methods for interacting with an on-chain instance of the
Orders contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<T: Transport + Clone, P: Provider<T, N>, N: Network> OrdersInstance<T, P, N>
Instantiation and getters/setters.
impl<T: Transport + Clone, P: Provider<T, N>, N: Network> OrdersInstance<T, P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, provider: P) -> Self
pub const fn new(address: Address, provider: P) -> Self
Creates a new wrapper around an on-chain Orders contract instance.
See the wrapper’s documentation for more details.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<T, P: Clone, N> OrdersInstance<T, &P, N>
impl<T, P: Clone, N> OrdersInstance<T, &P, N>
Sourcepub fn with_cloned_provider(self) -> OrdersInstance<T, P, N>
pub fn with_cloned_provider(self) -> OrdersInstance<T, P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<T: Transport + Clone, P: Provider<T, N>, N: Network> OrdersInstance<T, P, N>
Function calls.
impl<T: Transport + Clone, P: Provider<T, N>, N: Network> OrdersInstance<T, P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<T, &P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<T, &P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn fill(
&self,
outputs: Vec<<Output as SolType>::RustType>,
) -> SolCallBuilder<T, &P, fillCall, N>
pub fn fill( &self, outputs: Vec<<Output as SolType>::RustType>, ) -> SolCallBuilder<T, &P, fillCall, N>
Creates a new call builder for the [fill] function.
Sourcepub fn fillPermit2(
&self,
outputs: Vec<<Output as SolType>::RustType>,
permit2: <Permit2Batch as SolType>::RustType,
) -> SolCallBuilder<T, &P, fillPermit2Call, N>
pub fn fillPermit2( &self, outputs: Vec<<Output as SolType>::RustType>, permit2: <Permit2Batch as SolType>::RustType, ) -> SolCallBuilder<T, &P, fillPermit2Call, N>
Creates a new call builder for the [fillPermit2] function.
Sourcepub fn initiate(
&self,
deadline: U256,
inputs: Vec<<Input as SolType>::RustType>,
outputs: Vec<<Output as SolType>::RustType>,
) -> SolCallBuilder<T, &P, initiateCall, N>
pub fn initiate( &self, deadline: U256, inputs: Vec<<Input as SolType>::RustType>, outputs: Vec<<Output as SolType>::RustType>, ) -> SolCallBuilder<T, &P, initiateCall, N>
Creates a new call builder for the [initiate] function.
Sourcepub fn initiatePermit2(
&self,
tokenRecipient: Address,
outputs: Vec<<Output as SolType>::RustType>,
permit2: <Permit2Batch as SolType>::RustType,
) -> SolCallBuilder<T, &P, initiatePermit2Call, N>
pub fn initiatePermit2( &self, tokenRecipient: Address, outputs: Vec<<Output as SolType>::RustType>, permit2: <Permit2Batch as SolType>::RustType, ) -> SolCallBuilder<T, &P, initiatePermit2Call, N>
Creates a new call builder for the [initiatePermit2] function.
Sourcepub fn outputWitness(
&self,
outputs: Vec<<Output as SolType>::RustType>,
) -> SolCallBuilder<T, &P, outputWitnessCall, N>
pub fn outputWitness( &self, outputs: Vec<<Output as SolType>::RustType>, ) -> SolCallBuilder<T, &P, outputWitnessCall, N>
Creates a new call builder for the [outputWitness] function.
Sourceimpl<T: Transport + Clone, P: Provider<T, N>, N: Network> OrdersInstance<T, P, N>
Event filters.
impl<T: Transport + Clone, P: Provider<T, N>, N: Network> OrdersInstance<T, P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<T, &P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<T, &P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
Sourcepub fn Filled_filter(&self) -> Event<T, &P, Filled, N>
pub fn Filled_filter(&self) -> Event<T, &P, Filled, N>
Creates a new event filter for the Filled event.